## Django SAML2 Authentication Made Easy

### Dependencies

This plugin is compatible with Django 4.2+. The `pysaml2` Python
module is required.


### Install

You can install this plugin via `pip`:

    pip install djangosaml
